@@ -53,6 +53,7 @@ code from qwriter:
 #include <QXmlStreamReader>
 #include <QMimeData>
 #include <QFile>
+#include <QMessageBox>
 
 #include <QTimer>
 
@@ -822,7 +823,7 @@ CDocument::CDocument (CDox *hldr, QWidget *parent): QPlainTextEdit (parent)
 
   connect (this, SIGNAL(selectionChanged()), this, SLOT(slot_selectionChanged()));
   connect (this, SIGNAL(blockCountChanged(int)), this, SLOT(updateLineNumberAreaWidth()));
-  connect (this, SIGNAL(updateRequest(QRect, int)), this, SLOT(updateLineNumberArea(QRect, int)));
+  connect (this, SIGNAL(updateRequest(QRect,int)), this, SLOT(updateLineNumberArea(QRect,int)));
   connect (this, SIGNAL(cursorPositionChanged()), this, SLOT(cb_cursorPositionChanged()));
 
   updateLineNumberAreaWidth();
@@ -883,10 +884,12 @@ CDocument::~CDocument()
          if (QMessageBox::warning (0, "TEA",
                                    tr ("%1 has been modified.\n"
                                        "Do you want to save your changes?").arg (file_name),
-                                       QMessageBox::Yes | QMessageBox::Default,
-                                       QMessageBox::No | QMessageBox::Escape) == QMessageBox::Yes)
+                                       QMessageBox::Yes,
+                                       QMessageBox::No) == QMessageBox::Yes)
             file_save_with_name (file_name, charset);
 
+
+
   if (! file_name.startsWith (holder->dir_config) && ! file_name.endsWith (".notes"))
      {
       holder->add_to_recent (this);
@@ -1997,8 +2000,6 @@ CDox::CDox()
          timer_joystick.start();
      }
 #endif
-
-
 }
 
 
